#!/bin/bash

set -x

if [ -e "./isobuilder.func" ];then
	source ./isobuilder.func
elif [ -e "/usr/lib/isobuilder/isobuilder.func" ];then
	source /usr/lib/isobuilder/isobuilder.func
else
	echo "file: isobuiler.func is not found "
	exit 1
fi

if [ -e "/usr/lib/isobuilder/CONF.sh" ];then
	source /usr/lib/isobuilder/CONF.sh
else
	echo "file: CONF.sh is not exist"
	exit 1
fi


do_it()
{
	local TASK=$1

	[ ! -d "$WORK_DIR" ] && mkdir -pv $WORK_DIR
	[ ! -d "$TASK_DIR" ] && mkdir -pv $TASK_DIR
	[ ! -d "$PKG_DIR" ]  && mkdir -pv $PKG_DIR

	case $TASK in
		download_pkg)
			TMP_DIR=${WORK_DIR}/tmp && mkdir -pv $TMP_DIR

			if [ "$ISO_TYPE" == "cd"  ];then
				export PKG_LIST="$CD_LIST"
			elif [ "$ISO_TYPE" == "dvd"  ];then
				export PKG_LIST="$DVD_LIST"
			fi

			for deb_file in $PKG_LIST
			do
				DEB_PKG="$DEB_PKG,$(cat ${PRO_DIR}/data/${deb_file} |tr '\n\r' ',')"
			done
			debootstrap --download-only --no-check-gpg --include=$DEB_PKG --components=main,non-free,contrib --arch=$ARCH $DIST $TMP_DIR $MIRROR &>> $LOG_FILE
			for deb_file in $PKG_LIST
			do
				SEC_DEB_PKG="$SEC_DEB_PKG $(cat ${PRO_DIR}/data/${deb_file} |tr '\n\r' ' ')"
			done

			if [ "$?" == "0" ]; then

				cp -v ${TMP_DIR}/var/cache/apt/archives/*.deb $PKG_DIR
			else
				echo "deb pkg download is failed "
				exit 1
			fi

			for deb in $SEC_DEB_PKG
			do
				debootstrap --download-only --no-check-gpg --include=$deb --components=main,non-free,contrib --arch=$ARCH ${DIST}-security $TMP_DIR $MIRROR &>> $LOG_FILE
			done
			
			#if [ ! -n "$include_pkgs" ];then
			#	cp -v ${INCLUDE_DEB} $PKG_DIR/
			#	[ "$?" == "0" ] && echo "the pkg of local_pkg already includeded"
			#elif [ ! -n "$include_dir" ];then
			#	cp -v ${INCLUDE_DIR}/*.deb $PKG_DIR/
			#	cp -v ${INCLUDE_DIR}/*.udeb $PKG_DIR/
			#	[ "$?" == "0" ] && echo "the pkg of local_dir already includeded"
			#fi

			for UDEB in $(cat ${PRO_DIR}/data/debian-installer*)
			do
				INFO=$(get_pkg_info $UDEB $ARCH $DIST $MIRROR $TMP_DIR)
				MD5=$(get_pkg_md5 "$INFO")
				DLINK=$(get_pkg_path "$INFO")
				echo "$DLINK" >> $TMP_DIR/udeb-tmp.list
				cat $TMP_DIR/udeb-tmp.list | sort | uniq > $TMP_DIR/udeb.list
			done

			UDEBS=$(cat $TMP_DIR/udeb.list | awk '{print $1}')
			download_pkg "$UDEBS" $PKG_DIR $MIRROR &> $LOG_FILE
			if [ "$?" == "0" ]; then
				echo "udeb pkg is full download "
			else
				echo "udeb pkg download is failed "
				exit 1
			fi
			rm -rvf ${TMP_DIR}
			;;
		create_repo)
			mkdir -pv $WORK_DIR/mirror/conf
			bash ${PRO_DIR}/tools/gen_repo_conf.sh $DIST $ARCH ${WORK_DIR}/mirror/conf/distributions
			cd $WORK_DIR/mirror && reprepro includedeb $DIST $WORK_DIR/pkg/*.deb && reprepro includeudeb $DIST $WORK_DIR/pkg/*.udeb
			if [ "$?" == "0" ]; then
				echo "create repo is complete"
			else
				echo "create repo is failed"
			fi
			;;
		create_iso)
			mkdir -pv ${WORK_DIR}/{deepin-cd,output}
			mkdir -pv ${WORK_DIR}/deepin-cd/deepin/${DEBVERSION}/${CODENAME}
			if [ -d "${WORK_DIR}/deepin-cd" ];then
				cp -av ${DEEPIN_CD_DIR}/* $WORK_DIR/deepin-cd
				cp -v ${PRO_DIR}/data/deepin/${DEBVERSION}/${CODENAME}/splash.png ${WORK_DIR}/deepin-cd/deepin/${DEBVERSION}/${CODENAME}/
			fi

			bash ${PRO_DIR}/tools/gen_deepincd_startbuild.sh && echo "deepin_build.sh is ok"
			bash ${PRO_DIR}/tools/gen_deepincd_conf.sh && echo "deepincd_conf is ok"
			bash ${PRO_DIR}/tools/gen_deepincd_build.sh && echo "deepincd_buid is ok"

			if [ -n "$DIST" ];then
				cd ${WORK_DIR}/deepin-cd/data && ln -sv ${LINK_CODENAME} ${DIST} -f
				cd ${WORK_DIR}/deepin-cd/data/tasks && ln -sv ${LINK_CODENAME} ${DIST} -f
				cd ${WORK_DIR}/deepin-cd/tools/ && ln -sv ${LINK_CODENAME} ${DIST} -f
				cd ${WORK_DIR}/deepin-cd/tools/boot/ && ln -sv ${LINK_CODENAME} ${DIST} -f
			fi

			cd $WORK_DIR/deepin-cd/ && bash ./deepin_build.sh
			if [ "$?" == "0" ];then
				echo "iso is build ok"
			else
				echo "iso is build failed"
			fi
			;;
		clean_all)
			rm -rvf ${WORK_DIR}/tmp*
			rm -rvf ${WORK_DIR}/pkg
			rm -rvf ${WORK_DIR}/mirror
			rm -rvf ${WORK_DIR}/deepin-cd
			;;
		*)
			echo "Unkown option";;
	esac
}


get_help()
{
	#test -n "$@" && ec
	cat << EOF
Deepin-ISO-builder - create custom debian-installer CD/DVD

Usges:
	isobuiler [option] action 
 
[option]
--arch			specify  architecture ( i386,amd64, )                   [default is amd64 ]
--dist			specify distribution ( kui,sid )                        [default is kui ]
--mirror		specify apt-mirror   (http://url file://path )          [default is http://bj.packages.sndu.cn/debian/]
--include_pkg 		use the specified debian packages file (with full path) 
--include_dir		use the specified dir Contains debian packages

[action]

--download_pkg   download pkgs from apt-mirror
--create_repo    use download pkgs generate repo
--create_iso     use local repo generate iso
--clean_all      clean all builddir

example:

	isobuilder --arch amd64 --dist kui --download_pkg
	isobuilder --arch amd64 --dist kui --create_repo
	isobuilder --arch amd64 --dist kui --create_iso
EOF
}

cmd_opts="$@"
if [ -n "$cmd_opts" ];then
	while [ -n "$1" ]; do
	opt=${1}
	case "${opt}" in
		--arch)
			if [ -n "$2" ];then
				export ARCH="$2"
			fi
				shift && shift;;
		--dist)
			if [ -n "$2" ];then
				export DIST="$2"
			fi
				shift && shift;;
		--mirror)
			if [ -n "$2" ];then
				export MIRROR="$2"
			fi
				shift && shift;;
		--iso_type)
			if [ -n "$2" ];then
				export ISO_TYPE="$2"
			fi
				shift && shift;;
		--iso_name)
			if [ -n "$2" ];then
				export OUTFILE="$2"
			fi
				shift && shift;;
		--include_pkg)
			if [ -n "$2" ];then
				export INCLUDE_DEB="$2"
			fi
				shift && shift;;
		--include_dir)
			if [ -n "$2" ];then
				export INCLUDE_DIR="$2"
			fi
				shift && shift;;
		--download_pkg)
				TASK="download_pkg"
				shift ;;
		--create_repo)
				TASK="create_repo"
				shift ;;
		--create_iso)
				TASK="create_iso"
				shift ;;
		--clean_all)
				TASK="clean_all"
				shift ;;
		--help)
			get_help
			exit 0;;
		*)
			echo "Unknown options  please see help docs!" 
			get_help
			exit 0;;
	esac 
	done

	do_it $TASK
else
	get_help
fi
